Exception: Lutaml::Hal::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Lutaml::Hal::Error
- Defined in:
- lib/lutaml/hal/errors.rb
Direct Known Subclasses
BadRequestError, ConnectionError, ForbiddenError, LinkResolutionError, NotFoundError, ParsingError, ServerError, TimeoutError, TooManyRequestsError, UnauthorizedError
Instance Attribute Summary collapse
-
#response ⇒ Object
readonly
HTTP context for errors mapped from a response status, as
{ status: Integer, headers: Hash }.
Instance Method Summary collapse
-
#initialize(message = nil, response: nil) ⇒ Error
constructor
A new instance of Error.
Constructor Details
#initialize(message = nil, response: nil) ⇒ Error
Returns a new instance of Error.
10 11 12 13 |
# File 'lib/lutaml/hal/errors.rb', line 10 def initialize( = nil, response: nil) .nil? ? super() : super() @response = response end |
Instance Attribute Details
#response ⇒ Object (readonly)
HTTP context for errors mapped from a response status, as
{ status: Integer, headers: Hash }. Nil for locally raised errors.
8 9 10 |
# File 'lib/lutaml/hal/errors.rb', line 8 def response @response end |