Class: Lutaml::Hal::Page

Inherits:
Resource
  • Object
show all
Defined in:
lib/lutaml/hal/page.rb

Overview

Models the pagination of a collection of resources This class is used to represent the pagination information for a collection of resources in the HAL format.

Method Summary

Methods inherited from Resource

get_links_class, hal_link, inherited