Class: Lutaml::Hal::Page
- Defined in:
- lib/lutaml/hal/page.rb
Overview
Models the pagination of a collection of resources This class is used to represent the pagination information for a collection of resources in the HAL format.
Models the pagination of a collection of resources This class is used to represent the pagination information for a collection of resources in the HAL format.